/*
 * @Description: 
 * @Date: 2022-01-06 14:31:32
 * @LastEditors: CK.Zh
 * @LastEditTime: 2022-01-11 18:12:23
 * @FilePath: /motion_ec/board/board.h
 */
/*
 * Copyright (C) 2021, Huada Semiconductor Co., Ltd.
 *
 * SPDX-License-Identifier: Apache-2.0
 *
 * Change Logs:
 * Date           Author       Notes
 * 2021-08-19     pjq          first version
 */

#ifndef __BOARD_H__
#define __BOARD_H__

#include <rtthread.h>
#include "ddl.h"
#include "gpio.h"
#include "drv_gpio.h"

/* board configuration */
#define SRAM_BASE 0x20000000
#define SRAM_SIZE 0x2000
#define SRAM_END (SRAM_BASE + SRAM_SIZE)

/* High speed sram. */
#ifdef __CC_ARM
extern int Image$$RW_IRAM1$$ZI$$Limit;
#define HEAP_BEGIN              (&Image$$RW_IRAM1$$ZI$$Limit)
#elif __ICCARM__
#pragma section="CSTACK"
#define HEAP_BEGIN              (__segment_end("CSTACK"))
#else
extern int __bss_end;
#define HEAP_BEGIN              (&__bss_end)
#endif

#ifdef __ICCARM__
#define HEAP_END                SRAM_END
#else
#define HEAP_END                SRAM_END
#endif

//MISC
#define EC_PWR_BTN              GET_PIN(B, 11)
#define EC_PWR_LED_PIN          GET_PIN(B, 10)
#define EC_FUN_BTN              GET_PIN(B, 2)
#define EC_BUZZ_CTL_PIN         GET_PIN(B, 1)

//CAN
#define EC_CAN_TX               GET_PIN(B, 9)
#define EC_CAN_RX               GET_PIN(B, 8)
#define EC_CAN_STBY             GET_PIN(B, 7)

//Fan
#define EC_FAN_SNS              GET_PIN(C, 6)
#define EC_FAN_CTL              GET_PIN(B, 15)

//I2C0
#define EC_I2C0_SDA             GET_PIN(A, 10)
#define EC_I2C0_SCL             GET_PIN(A, 9)

//I21
#define EC_I2C1_SDA             GET_PIN(B, 14)
#define EC_I2C1_SCL             GET_PIN(B, 13)

//ADC
#define EC_ADC_5V0_B            GET_PIN(A, 4)
#define EC_ADC_5V0_A            GET_PIN(A, 5)
#define EC_ADC_12V0             GET_PIN(A, 6)
#define EC_ADC_BKP_BAT          GET_PIN(A, 5)
#define EC_ADC_MAIN_PWR         GET_PIN(C, 4)
#define EC_ADC_MON_EN           GET_PIN(C, 5)

//PMB Interface
#define PMB_PS_ON               GET_PIN(C, 0)
#define PMB_TEMP_SEN_EN         GET_PIN(C, 1)
#define PMB_TEMP_SEN_ALT        GET_PIN(C, 2)
#define PMB_CHRG_STAT2          GET_PIN(C, 3)
#define PMB_CHRG_STAT1          GET_PIN(A, 0)
#define PMB_CHRG_SHDN           GET_PIN(A, 1)
#define PMB_COULOMB_ALCC        GET_PIN(A, 2)

//SOM Management Interface
#define SOM_MGT_SYS_RESET       GET_PIN(B, 6)
#define SOM_MGT_FORCE_REC       GET_PIN(B, 5)
#define SOM_MGT_MOD_SLEEP       GET_PIN(B, 4)
#define SOM_MGT_SHDN_REQ        GET_PIN(B, 3)
#define SOM_MGT_POWER_EN        GET_PIN(D, 2)
#define SOM_MGT_SLEEP_WAKE      GET_PIN(C, 12)









void rt_hw_board_init(void);
void rt_hw_us_delay(rt_uint32_t us);



#endif

// <<< Use Configuration Wizard in Context Menu >>>
